import { cn } from "@/common/utils";
import Link from "next/link";
import { ReactElement } from "react";

type ButtonProps = {
  /**
   * The title of the button.
   */
  title: string;

  /**
   * The URL to go to.
   */
  url: string;

  /**
   * Whether clicking the button will
   * open the link in a new tab.
   */
  openInNewTab?: boolean;

  /**
   * The class names for the button.
   */
  className?: string;
};

export function HrefButton({ title, url, openInNewTab, className }: ButtonProps): ReactElement {
  return (
    <div className={cn("w-fit", className)}>
      <Link href={url} target={openInNewTab ? "_blank" : ""}>
        <p className="hover:text-primary transition-all">{title}</p>
      </Link>
    </div>
  );
}
