import { CachedBedrockMinecraftServer, CachedJavaMinecraftServer } from "mcutils-library";
import Image from "next/image";
import { ReactElement } from "react";
import { CodeDialog } from "../code-dialog";
import { Button } from "../ui/button";
import config from "@root/config.json";
import { cn } from "@/common/utils";
import { minecraft } from "@/app/font/fonts";
import { CacheInformation } from "@/app/components/cache-information";

type ServerViewProps = {
  /**
   * The server to display.
   */
  server: CachedJavaMinecraftServer | CachedBedrockMinecraftServer;

  /**
   * The favicon for the server.
   */
  favicon: string | undefined;
};

export function ServerView({ server, favicon }: ServerViewProps): ReactElement {
  return (
    <div className="flex relative flex-col gap-2 items-center w-screen">
      <div
        className={cn(
          "w-[29rem] relative p-2 flex gap-2 rounded-lg pointer-events-none scale-75 xs:scale-100",
          'bg-[url("/media/server-background.png")]',
        )}
      >
        {/* Favicon */}
        <Image
          src={favicon || `${config.apiEndpoint}/server/icon/fallback`}
          alt={`${server.hostname}'s Favicon`}
          width={64}
          height={64}
        />

        {/* Name & MOTD */}
        <div className={cn("flex flex-col leading-[1.3rem]", minecraft.className)}>
          <h1>{server.hostname}</h1>
          {server.motd.html.map((line: string, index: number): ReactElement => {
            return <p key={index} className="pointer-events-auto" dangerouslySetInnerHTML={{ __html: line }}></p>;
          })}
        </div>

        {/* Ping */}
        <div className={cn("absolute top-0.5 right-0.5 flex items-center", minecraft.className)}>
          <p>
            {server.players.online}/{server.players.max}
          </p>
          <Image src="/media/full-ping.png" alt="Ping!" width={28} height={28} />
        </div>
      </div>
      <div className="flex gap-2 flex-wrap justify-center">
        <CodeDialog
          title="Server Data"
          description="The servers's data from the API"
          code={JSON.stringify(server, undefined, 2)}
        >
          <Button>View as JSON</Button>
        </CodeDialog>
        <CacheInformation cache={server.cache}>
          <Button>Cache Information</Button>
        </CacheInformation>
      </div>
    </div>
  );
}
